// +-------------------------------- DISCLAIMER ---------------------------------+
// |                                                                             |
// | This application program is provided to you free of charge as an example.   |
// | Despite the considerable efforts of Euresys personnel to create a usable    |
// | example, you should not assume that this program is error-free or suitable  |
// | for any purpose whatsoever.                                                 |
// |                                                                             |
// | EURESYS does not give any representation, warranty or undertaking that this |
// | program is free of any defect or error or suitable for any purpose. EURESYS |
// | shall not be liable, in contract, in torts or otherwise, for any damages,   |
// | loss, costs, expenses or other claims for compensation, including those     |
// | asserted by third parties, arising out of or in connection with the use of  |
// | this program.                                                               |
// |                                                                             |
// +-----------------------------------------------------------------------------+
//
// ImageProcessing.cs: implementation of the ImageProcessing class.
//
//////////////////////////////////////////////////////////////////////

using System;
using System.Collections.Generic;
using System.Text;
using System.Drawing;
using System.Windows.Forms;

/// Open eVision Namespace
using Euresys.Open_eVision_1_2;


namespace LotMixingOnline
{

    class ImageProcessing
    {
        /// Source and temporary images
        private EImageBW8   m_SrcImg = new EImageBW8();
        private EImageBW8   m_RotatedImg = new EImageBW8();

        /// ROI for OCR Operation
        private EROIBW8     m_Roi = new EROIBW8();
     
        /// EasyOCR Object
        private EOCR		m_Ocr = new EOCR();

        /// ERectangleGauge Object to detect device body
        private ERectangleGauge m_RectGauge = new ERectangleGauge();

        /// Recognized string
        private string	m_Str ;

        /// <summary>
        /// Constructor
        /// </summary>
        public ImageProcessing()
        {

        }

        /// <summary>
        /// Destructor
        /// </summary>
        ~ImageProcessing()
        {

        }

        /// <summary>
        /// Initialization
        /// </summary>
        public void Initialize()
        {

            try
            {
                /// Load the EasyOCR font file 
                m_Ocr.Load(@"..\..\..\..\Resources\font\OCR-B.ocr");
                m_Ocr.TextColor = EOCRColor.WhiteOnBlack;

                /// Set the Rectangle Gauge Parameters
                m_RectGauge.Tolerance = 100.00f;
                m_RectGauge.SetCenterXY(296.00f, 258.00f);
                m_RectGauge.SetSize(375, 300);

                m_RectGauge.MinAmplitude= 3;
                m_RectGauge.Threshold = 5;
                m_RectGauge.Thickness= 3;

                m_RectGauge.TransitionChoice= ETransitionChoice.NthFromBegin;
                m_RectGauge.TransitionType= ETransitionType.Wb;

                m_RectGauge.NumFilteringPasses = 5;
                m_RectGauge.FilteringThreshold= 2.1f;
                m_RectGauge.SamplingStep = 10;
              
          }
          catch (EException exc)
          {
              MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
          }

        }


        /// <summary>
        /// Drawing
        /// </summary>
        public void Draw(Graphics g)
        {
            // Specify the color for drawing
            Brush m_WhiteBrush = new SolidBrush(Color.White );
            Font m_Font= new Font("Arial", 11);

            try
            {

                /// Exit if no image has been loaded
                if (m_SrcImg.IsVoid)
                    return;

                /// Draw the source image
                m_SrcImg.Draw(g);

                /// Draw the device bounding box
                m_RectGauge.Draw(g, EDrawingMode.Actual );

                /// Draw result string
                g.DrawString(m_Str, m_Font, m_WhiteBrush, 20, 20);    
             
            }
            catch (EException exc)
            {
                MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }


        }

        /// <summary>
        /// Inspection
        /// </summary>
        public void Inspect(string filename)
        {

            ERectangle d_MeasuredRectangle; // ERectangle instance

            try
            {
                /// Load the image for inspection
                m_SrcImg.Load(filename);
                m_RotatedImg.SetSize(m_SrcImg);

                /// Detect Body edge with the ERectangleGauge tool
                m_RectGauge.Measure (m_SrcImg);
                d_MeasuredRectangle = m_RectGauge.MeasuredRectangle;

                /// Rotate the image to prepare for OCR operation
                EasyImage.ScaleRotate(m_SrcImg, d_MeasuredRectangle.CenterX, d_MeasuredRectangle.CenterY, m_RotatedImg.Width / 2, m_RotatedImg.Height / 2, 1.00f, 1.00f, d_MeasuredRectangle.Angle, m_RotatedImg, 8);

                /// Place ROI for OCR operation
                m_Roi.Attach(m_RotatedImg);
                m_Roi.SetPlacement(m_RotatedImg.Width /2 - 175, m_RotatedImg.Height /2 - 125, 350, 250);

                /// OCR operation
                m_Str = m_Ocr.Recognize(m_Roi, 7, (int)EOCRClass.AllClasses);
            
            }
            catch (EException exc)
            {
                MessageBox.Show(exc.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }

    }
}


